summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ChangeLog7
-rw-r--r--generic/tkImgPhoto.c6
2 files changed, 9 insertions, 4 deletions
diff --git a/ChangeLog b/ChangeLog
index 4eb7554..a775e7c 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,9 +1,14 @@
-2012-01-?? Francois Vogel <fvogelnew1@free.fr>
+2012-01-26 Francois Vogel <fvogelnew1@free.fr>
* generic/tkTextDisp.c: [Bug-1754043] and [Bug-2321450]: When
-blockcursor is true, the cursor appears as a blinking bar which
expands to the right edge of the widget.
+2012-01-25 Jan Nijtmans <nijtmans@users.sf.net>
+
+ * generic/tkImgPhoto.c: [Bug 2433260]: non-critical error in
+ Tk_PhotoPutBlock
+
2012-01-25 Francois Vogel <fvogelnew1@free.fr>
* generic/tkText.c: Don't increase the epoch twice
diff --git a/generic/tkImgPhoto.c b/generic/tkImgPhoto.c
index ef907e6..a6df6ef 100644
--- a/generic/tkImgPhoto.c
+++ b/generic/tkImgPhoto.c
@@ -4387,7 +4387,7 @@ Tk_PhotoPutBlock(
/*
* Copy the data into our local 32-bit/pixel array. If we can do it with a
* single memcpy, we do.
*/
destLinePtr = masterPtr->pix32 + (y * masterPtr->width + x) * 4;
@@ -4395,7 +4395,7 @@ Tk_PhotoPutBlock(
/*
* Test to see if we can do the whole write in a single copy. This test is
* probably too restrictive. We should also be able to do a memcpy if
* pixelSize == 3 and alphaOffset == 0. Maybe other cases too.
*/
@@ -4405,7 +4405,7 @@ Tk_PhotoPutBlock(
&& ((height == 1) || ((x == 0) && (width == masterPtr->width)
&& (blockPtr->pitch == pitch)))
&& (compRule == TK_PHOTO_COMPOSITE_SET)) {
- memcpy(destLinePtr, blockPtr->pixelPtr + blockPtr->offset[0],
+ memmove(destLinePtr, blockPtr->pixelPtr + blockPtr->offset[0],
(size_t) (height * width * 4));
/*
@@ -4387,7 +4387,7 @@ Tk_PhotoPutBlock(
/*
* Copy the data into our local 32-bit/pixel array. If we can do it with a
- * single memcpy, we do.
+ * single memmove, we do.
*/
destLinePtr = masterPtr->pix32 + (y * masterPtr->width + x) * 4;
@@ -4395,7 +4395,7 @@ Tk_PhotoPutBlock(
/*
* Test to see if we can do the whole write in a single copy. This test is
- * probably too restrictive. We should also be able to do a memcpy if
+ * probably too restrictive. We should also be able to do a memmove if
* pixelSize == 3 and alphaOffset == 0. Maybe other cases too.
*/